@@ -37,6 +37,8 @@
 #include <kdebug.h>
 #include <ksplashscreen.h>
 #include <ktexteditor/cursor.h>
+#include <KMessageBox>
+#include <KProcess>
 
 #include <QFileInfo>
 #include <QPixmap>
@@ -47,6 +49,7 @@
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <QTextStream>
 
 #include <shell/core.h>
 #include <shell/mainwindow.h>
@@ -62,11 +65,9 @@
 
 #include "kdevideextension.h"
 
-#include <KMessageBox>
-#include <KProcess>
-
 #include <iostream>
-#include <QtCore/QTextStream>
+
+#include "welcomepage/welcomepageview.h"
 
 using KDevelop::Core;
 
@@ -182,6 +183,7 @@ int main( int argc, char *argv[] )
            .add("open-session <session>", ki18n("Open KDevelop with the given session.\n"
                                            "You can pass either hash or the name of the session." ));
     options.add("ps").add("pick-session", ki18n("Shows all available sessions and lets you select one to open." ));
+    options.add("pss").add("pick-session-shell", ki18n("List all available sessions on shell and lets you select one to open." ));
     options.add("l")
            .add("list-sessions", ki18n( "List available sessions and quit." ));
     options.add("p")
@@ -230,6 +232,40 @@ int main( int argc, char *argv[] )
     // if empty, restart kdevelop with last active session, see SessionController::defaultSessionId
     QString session;
     
+    if(args->isSet("pss"))
+    {
+        QTextStream qerr(stderr);
+        QList<KDevelop::SessionInfo> candidates;
+        foreach(const KDevelop::SessionInfo& si, KDevelop::SessionController::availableSessionInfo())
+            if( (!si.name.isEmpty() || !si.projects.isEmpty() || args->isSet("pid")) &&
+                (!args->isSet("pid") || !KDevelop::SessionController::tryLockSession(si.uuid.toString())))
+                candidates << si;
+        
+        if(candidates.size() == 0)
+        {
+            qerr << "no session available" << endl;
+            return 1;
+        }
+        
+        if(candidates.size() == 1 && args->isSet("pid"))
+        {
+            session = candidates[0].uuid.toString();
+        }else{
+            for(int i = 0; i < candidates.size(); ++i)
+                qerr << "[" << i << "]: " << candidates[i].description << endl;
+            
+            int chosen;
+            std::cin >> chosen;
+            if(chosen >= 0 && chosen < candidates.size())
+            {
+                session = candidates[chosen].uuid.toString();
+            }else{
+                qerr << "bad pick" << endl;
+                return 1;
+            }
+        }
+    }
+    
     if(args->isSet("ps"))
     {
         bool onlyRunning = args->isSet("pid");
@@ -326,7 +362,7 @@ int main( int argc, char *argv[] )
                                   session, state.holderApp, state.holderHostname, state.holderPid );
 
             KGuiItem overwrite = KStandardGuiItem::cont();
-            overwrite.setText(i18n("remove lock file"));
+            overwrite.setText(i18n("Remove lock file"));
             KGuiItem cancel = KStandardGuiItem::quit();
             int ret = KMessageBox::warningYesNo(0, errmsg, i18n("Failed to Lock Session %1", session),
                                                 overwrite, cancel, QString() );
@@ -476,5 +512,8 @@ int main( int argc, char *argv[] )
         args->clear();
     }
 
+#ifdef WITH_WELCOMEPAGE
+    trySetupWelcomePageView();
+#endif
     return app.exec();
 }
