@@ -37,8 +37,16 @@ class QStringPrinter:
         #        ret += chr(char)
         #    i = i + 1
         #return ret
-        dataAsCharPointer = self.val['d']['data'].cast(gdb.lookup_type("char").pointer())
-        return dataAsCharPointer.string(encoding = 'UTF-16', length = size * 2)
+        ret = ""
+        # The QString object might be not yet initialized. In this case size is a bogus value
+        # and the following 2 lines might throw memory access error. Hence the try/catch.
+        try:
+            dataAsCharPointer = self.val['d']['data'].cast(gdb.lookup_type("char").pointer())
+            ret = dataAsCharPointer.string(encoding = 'UTF-16', length = size * 2)
+        except Exception:
+            # swallow the exception and return empty string
+            pass
+        return ret
 
     def display_hint (self):
         return 'string'
@@ -96,21 +104,21 @@ class QListPrinter:
             #from QTypeInfo::isLarge
             isLarge = self.nodetype.sizeof > gdb.lookup_type('void').pointer().sizeof
 
-            #isStatic is not needed anymore since Qt 4.6
-            #isPointer = self.nodetype.code == gdb.TYPE_CODE_PTR
-            #
-            ##unfortunately we can't use QTypeInfo<T>::isStatic as it's all inlined, so use
-            ##this list of types that use Q_DECLARE_TYPEINFO(T, Q_MOVABLE_TYPE)
-            ##(obviously it won't work for custom types)
-            #movableTypes = ['QRect', 'QRectF', 'QString', 'QMargins', 'QLocale', 'QChar', 'QDate', 'QTime', 'QDateTime', 'QVector',
-            #    'QRegExpr', 'QPoint', 'QPointF', 'QByteArray', 'QSize', 'QSizeF', 'QBitArray', 'QLine', 'QLineF', 'QModelIndex', 'QPersitentModelIndex',
-            #    'QVariant', 'QFileInfo', 'QUrl', 'QXmlStreamAttribute', 'QXmlStreamNamespaceDeclaration', 'QXmlStreamNotationDeclaration',
-            #    'QXmlStreamEntityDeclaration']
-            #if movableTypes.count(self.nodetype.tag):
-            #    isStatic = False
-            #else:
-            #    isStatic = not isPointer
-            isStatic = False
+            isPointer = self.nodetype.code == gdb.TYPE_CODE_PTR
+
+            #unfortunately we can't use QTypeInfo<T>::isStatic as it's all inlined, so use
+            #this list of types that use Q_DECLARE_TYPEINFO(T, Q_MOVABLE_TYPE)
+            #(obviously it won't work for custom types)
+            movableTypes = ['QRect', 'QRectF', 'QString', 'QMargins', 'QLocale', 'QChar', 'QDate', 'QTime', 'QDateTime', 'QVector',
+               'QRegExpr', 'QPoint', 'QPointF', 'QByteArray', 'QSize', 'QSizeF', 'QBitArray', 'QLine', 'QLineF', 'QModelIndex', 'QPersitentModelIndex',
+               'QVariant', 'QFileInfo', 'QUrl', 'QXmlStreamAttribute', 'QXmlStreamNamespaceDeclaration', 'QXmlStreamNotationDeclaration',
+               'QXmlStreamEntityDeclaration']
+            #this list of types that use Q_DECLARE_TYPEINFO(T, Q_PRIMITIVE_TYPE) (from qglobal.h)
+            primitiveTypes = ['bool', 'char', 'signed char', 'uchar', 'short', 'ushort', 'int', 'uint', 'long', 'ulong', 'qint64', 'qunit64', 'float', 'double']
+            if movableTypes.count(self.nodetype.tag) or primitiveTypes.count(str(self.nodetype)):
+               isStatic = False
+            else:
+                isStatic = not isPointer
 
             if isLarge or isStatic: #see QList::Node::t()
                 node = array.cast(gdb.lookup_type('QList<%s>::Node' % self.nodetype).pointer())
@@ -119,8 +127,9 @@ class QListPrinter:
             self.count = self.count + 1
             return ('[%d]' % count, node['v'].cast(self.nodetype))
 
-    def __init__(self, val, itype):
+    def __init__(self, val, container, itype):
         self.val = val
+        self.container = container
         if itype == None:
             self.itype = self.val.type.template_argument(0)
         else:
@@ -135,7 +144,82 @@ class QListPrinter:
         else:
             empty = ""
 
-        return "%sQList<%s>" % ( empty , self.itype )
+        return "%s%s<%s>" % ( empty, self.container, self.itype )
+
+class QVectorPrinter:
+    "Print a QVector"
+
+    class _iterator:
+        def __init__(self, nodetype, d, p):
+            self.nodetype = nodetype
+            self.d = d
+            self.p = p
+            self.count = 0
+
+        def __iter__(self):
+            return self
+
+        def next(self):
+            if self.count >= self.p['size']:
+                raise StopIteration
+            count = self.count
+
+            self.count = self.count + 1
+            return ('[%d]' % count, self.p['array'][count])
+
+    def __init__(self, val, container):
+        self.val = val
+        self.container = container
+        self.itype = self.val.type.template_argument(0)
+
+    def children(self):
+        return self._iterator(self.itype, self.val['d'], self.val['p'])
+
+    def to_string(self):
+        if self.val['d']['size'] == 0:
+            empty = "empty "
+        else:
+            empty = ""
+
+        return "%s%s<%s>" % ( empty, self.container, self.itype )
+
+class QLinkedListPrinter:
+    "Print a QLinkedList"
+
+    class _iterator:
+        def __init__(self, nodetype, begin, size):
+            self.nodetype = nodetype
+            self.it = begin
+            self.pos = 0
+            self.size = size
+
+        def __iter__(self):
+            return self
+
+        def next(self):
+            if self.pos >= self.size:
+                raise StopIteration
+
+            pos = self.pos
+            val = self.it['t']
+            self.it = self.it['n']
+            self.pos = self.pos + 1
+            return ('[%d]' % pos, val)
+
+    def __init__(self, val):
+        self.val = val
+        self.itype = self.val.type.template_argument(0)
+
+    def children(self):
+        return self._iterator(self.itype, self.val['e']['n'], self.val['d']['size'])
+
+    def to_string(self):
+        if self.val['d']['size'] == 0:
+            empty = "empty "
+        else:
+            empty = ""
+
+        return "%sQLinkedList<%s>" % ( empty, self.itype )
 
 class QMapPrinter:
     "Print a QMap"
@@ -152,6 +236,11 @@ class QMapPrinter:
             return self
 
         def payload (self):
+            if gdb.parse_and_eval:
+                ret = int(gdb.parse_and_eval('QMap<%s, %s>::payload()' % (self.ktype, self.vtype)))
+                if (ret): return ret;
+            
+            #if the inferior function call didn't work, let's try to calculate ourselves
 
             #we can't use QMapPayloadNode as it's inlined
             #as a workaround take the sum of sizeof(members)
@@ -164,7 +253,12 @@ class QMapPrinter:
             #TODO: find a real solution for this problem
             ret += ret % gdb.lookup_type('void').pointer().sizeof
 
+            #for some reason booleans are different
+            if str(self.vtype) == 'bool':
+                ret += 2
+
             ret -= gdb.lookup_type('void').pointer().sizeof
+            
             return ret
 
         def concrete (self, data_node):
@@ -186,8 +280,9 @@ class QMapPrinter:
             return result
 
 
-    def __init__(self, val):
+    def __init__(self, val, container):
         self.val = val
+        self.container = container
 
     def children(self):
         return self._iterator(self.val)
@@ -198,7 +293,7 @@ class QMapPrinter:
         else:
             empty = ""
 
-        return "%sQMap<%s, %s>" % ( empty , self.val.type.template_argument(0), self.val.type.template_argument(1) )
+        return "%s%s<%s, %s>" % ( empty, self.container, self.val.type.template_argument(0), self.val.type.template_argument(1) )
 
     def display_hint (self):
         return 'map'
@@ -295,8 +390,9 @@ class QHashPrinter:
             self.count = self.count + 1
             return ('[%d]' % self.count, item)
 
-    def __init__(self, val):
+    def __init__(self, val, container):
         self.val = val
+        self.container = container
 
     def children(self):
         return self._iterator(self.val)
@@ -307,7 +403,7 @@ class QHashPrinter:
         else:
             empty = ""
 
-        return "%sQHash<%s, %s>" % ( empty , self.val.type.template_argument(0), self.val.type.template_argument(1) )
+        return "%s%s<%s, %s>" % ( empty, self.container, self.val.type.template_argument(0), self.val.type.template_argument(1) )
 
     def display_hint (self):
         return 'map'
@@ -437,12 +533,17 @@ class QSetPrinter:
             return ('[%d]' % (self.count-1), item)
 
     def children(self):
-        hashPrinter = QHashPrinter(self.val['q_hash'])
+        hashPrinter = QHashPrinter(self.val['q_hash'], None)
         hashIterator = hashPrinter._iterator(self.val['q_hash'])
         return self._iterator(hashIterator)
 
     def to_string(self):
-        return 'QSet'
+        if self.val['q_hash']['d']['size'] == 0:
+            empty = "empty "
+        else:
+            empty = ""
+
+        return "%sQSet<%s>" % ( empty , self.val.type.template_argument(0) )
 
 
 class QCharPrinter:
@@ -456,6 +557,21 @@ class QCharPrinter:
     def display_hint (self):
         return 'string'
 
+class QUuidPrinter:
+
+    def __init__(self, val):
+        self.val = val
+
+    def to_string(self):
+        return "QUuid({%x-%x-%x-%x%x-%x%x%x%x%x%x})" % (self.val['data1'], self.val['data2'], self.val['data3'],
+                                            self.val['data4'][0], self.val['data4'][1],
+                                            self.val['data4'][2], self.val['data4'][3],
+                                            self.val['data4'][4], self.val['data4'][5],
+                                            self.val['data4'][6], self.val['data4'][7])
+
+    def display_hint (self):
+        return 'string'
+
 def register_qt4_printers (obj):
     if obj == None:
         obj = gdb
@@ -493,16 +609,23 @@ def lookup_function (val):
 def build_dictionary ():
     pretty_printers_dict[re.compile('^QString$')] = lambda val: QStringPrinter(val)
     pretty_printers_dict[re.compile('^QByteArray$')] = lambda val: QByteArrayPrinter(val)
-    pretty_printers_dict[re.compile('^QList<.*>$')] = lambda val: QListPrinter(val, None)
-    pretty_printers_dict[re.compile('^QStringList$')] = lambda val: QListPrinter(val, 'QString')
-    pretty_printers_dict[re.compile('^QMap<.*>$')] = lambda val: QMapPrinter(val)
-    pretty_printers_dict[re.compile('^QHash<.*>$')] = lambda val: QHashPrinter(val)
+    pretty_printers_dict[re.compile('^QList<.*>$')] = lambda val: QListPrinter(val, 'QList', None)
+    pretty_printers_dict[re.compile('^QStringList$')] = lambda val: QListPrinter(val, 'QStringList', 'QString')
+    pretty_printers_dict[re.compile('^QQueue')] = lambda val: QListPrinter(val, 'QQueue', None)
+    pretty_printers_dict[re.compile('^QVector<.*>$')] = lambda val: QVectorPrinter(val, 'QVector')
+    pretty_printers_dict[re.compile('^QStack<.*>$')] = lambda val: QVectorPrinter(val, 'QStack')
+    pretty_printers_dict[re.compile('^QLinkedList<.*>$')] = lambda val: QLinkedListPrinter(val)
+    pretty_printers_dict[re.compile('^QMap<.*>$')] = lambda val: QMapPrinter(val, 'QMap')
+    pretty_printers_dict[re.compile('^QMultiMap<.*>$')] = lambda val: QMapPrinter(val, 'QMultiMap')
+    pretty_printers_dict[re.compile('^QHash<.*>$')] = lambda val: QHashPrinter(val, 'QHash')
+    pretty_printers_dict[re.compile('^QMultiHash<.*>$')] = lambda val: QHashPrinter(val, 'QMultiHash')
     pretty_printers_dict[re.compile('^QDate$')] = lambda val: QDatePrinter(val)
     pretty_printers_dict[re.compile('^QTime$')] = lambda val: QTimePrinter(val)
     pretty_printers_dict[re.compile('^QDateTime$')] = lambda val: QDateTimePrinter(val)
     pretty_printers_dict[re.compile('^QUrl$')] = lambda val: QUrlPrinter(val)
     pretty_printers_dict[re.compile('^QSet<.*>$')] = lambda val: QSetPrinter(val)
     pretty_printers_dict[re.compile('^QChar$')] = lambda val: QCharPrinter(val)
+    pretty_printers_dict[re.compile('^QUuid')] = lambda val: QUuidPrinter(val)
 
 
 pretty_printers_dict = {}
