@@ -115,6 +115,11 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
     KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
     if(m_declaration) {
       newText = m_declaration->identifier().toString();
+      if(prependScopePrefix) {
+        QualifiedIdentifier parentScope = Cpp::stripPrefixes(m_completionContext->duContext(), m_declaration->context()->scopeIdentifier(true));
+        if(!parentScope.isEmpty())
+            newText.prepend (parentScope.toString() + "::");
+      }
     } else {
       kDebug() << "Declaration disappeared";
       if(!alternativeText.isEmpty())
@@ -296,21 +301,13 @@ KTextEditor::CodeCompletionModel::CompletionProperties NormalDeclarationCompleti
     }
 
     switch (dec->abstractType()->whichType()) {
-      case AbstractType::TypeIntegral:
-        if (dec->type<EnumerationType>()) {
-          // Remove variable bit set in DUChainUtils
-          p &= ~CodeCompletionModel::Variable;
-          p |= CodeCompletionModel::Enum;
-        }
-        if (dec->type<EnumeratorType>()) {
+      case AbstractType::TypeEnumerator:
           //Get the properties from the parent, because that may contain information like "private"
           if(dec->context()->owner()) {
             p = DUChainUtils::completionProperties(dec->context()->owner());
+            p &= ~CodeCompletionModel::Enum;
+            p |=  CodeCompletionModel::Variable;
           }
-          // Remove variable bit set in DUChainUtils
-          p &= 0xffffffff - CodeCompletionModel::Variable;
-          p |= CodeCompletionModel::Enum;
-        }
         break;
       case AbstractType::TypeStructure:
         if (CppClassType::Ptr classType =  dec->type<CppClassType>())
