@@ -83,6 +83,8 @@ private slots:
   void testSearchAcrossNamespace2();
   void testSearchAcrossNamespace3();
   void testADL();
+  void testADLConstness();
+  void testADLConstness2();
   void testADLClassType();
   void testADLFunctionType();
   void testADLFunctionByName();
@@ -189,10 +191,13 @@ private slots:
   void testNestedNamespace();
   
   void testDeclarationHasUses();
+  void testBug269352();
+  void testRenameClass();
 
   //BEGIN C++2011
   void testRangeBasedFor();
   void testRangeBasedForClass();
+  void testRangeBasedForClass2();
   void testRValueReference();
   void testDefaultDelete();
   void testDelete_Bug278781();
@@ -212,6 +217,7 @@ private slots:
   void testTemplateSpecializeRValue();
   void testAliasDeclaration();
   void testAuto();
+  void testNoexcept();
   //END C++2011
 
 private:
