@@ -40,6 +40,7 @@ protected:
   virtual void visitBaseClause (BaseClauseAST*);
   virtual void visitBaseSpecifier (BaseSpecifierAST*);
   virtual void visitBinaryExpression (BinaryExpressionAST*);
+  virtual void visitBracedInitList (BracedInitListAST*);
   virtual void visitCastExpression (CastExpressionAST*);
   virtual void visitClassMemberAccess (ClassMemberAccessAST*);
   virtual void visitClassSpecifier (ClassSpecifierAST*);
@@ -66,6 +67,7 @@ protected:
   virtual void visitInitDeclarator (InitDeclaratorAST*);
   virtual void visitInitializer (InitializerAST*);
   virtual void visitInitializerClause (InitializerClauseAST*);
+  virtual void visitInitializerList (InitializerListAST* );
   virtual void visitJumpStatement (JumpStatementAST*);
   virtual void visitLabeledStatement (LabeledStatementAST*);
   virtual void visitLinkageBody (LinkageBodyAST*);
