@@ -20,6 +20,8 @@
 #ifndef PARSER_H
 #define PARSER_H
 
+#include "config.h"
+
 #include "ast.h"
 #include "lexer.h"
 #include "commentparser.h"
@@ -30,18 +32,18 @@
 #include <cppparserexport.h>
 #include "commentformatter.h"
 
-#ifdef Q_CC_MSVC
-#include <hash_map>
-using namespace stdext;
-
-#elif defined GXX_LT_4_3
-#include <ext/hash_map>
-using namespace __gnu_cxx;
-
-#else // CXX-0
+#if defined(HAVE_UNORDERED_MAP) // CXX-0
 #include <unordered_map>
 template <class Key, class Data>
 class  hash_map : public std::unordered_map<Key, Data> { };
+
+#elif defined(HAVE_EXT_HASH_MAP)
+#include <ext/hash_map>
+using namespace __gnu_cxx;
+
+#elif defined(Q_CC_MSVC)
+#include <hash_map>
+using namespace stdext;
 #endif
 
 class TokenStream;
@@ -98,7 +100,7 @@ private:
   /**Convenience method to report problems. Constructs the problem
   using the information about the current line and column in the buffer
   that is being parsed. Then stores the problem in the control object.*/
-  void reportError(const QString& msg);
+  void reportError(const QString& msg, KDevelop::ProblemData::Severity severity = KDevelop::ProblemData::Error);
   /**Reports a syntax error about unexpected token. The token
   reported is LA (look-ahead) from the stream.*/
   void syntaxError();
@@ -159,6 +161,7 @@ public:
   bool parseInitDeclarator(InitDeclaratorAST *&node);
   bool parseInitDeclaratorList(const ListNode<InitDeclaratorAST*> *&node);
   bool parseInitializer(InitializerAST *&node);
+  bool parseDesignatedInitializer(InitializerClauseAST *&node);
   bool parseInitializerClause(InitializerClauseAST *&node);
   bool parseInitializerList(InitializerListAST *&node);
   bool parseJumpStatement(StatementAST *&node);
@@ -234,6 +237,8 @@ public:
   bool parseLambdaExpression(ExpressionAST *&node);
   bool parseLambdaCapture(LambdaCaptureAST *&node);
   bool parseLambdaDeclarator(LambdaDeclaratorAST *&node);
+  bool parseMemberVirtSpecifier(const ListNode<uint> *&node);
+  bool parseClassVirtSpecifier(const ListNode<uint> *&node);
 
   bool skipUntil(int token);
   bool skipUntilDeclaration();
