@@ -404,6 +404,7 @@ void TestParser::testInitList_data()
   QTest::newRow("ctor-explicit2") << "void foo() { double{1}; };"; // explicitly construct a double
   QTest::newRow("map") << "std::map<std::string,int> anim = { {\"bear\",4}, {\"cassowary\",2}, {\"tiger\",7} };";
   QTest::newRow("operator[]") << "void foo() { x[{1,2,3}] = 7; }"; // 5.2.1
+  QTest::newRow("member") << "class a { a() : b{1,2,3} {} int b[3]; };";
 }
 
 void TestParser::testInitList()
@@ -434,9 +435,9 @@ void TestParser::testInitListFalsePositives()
   FunctionDefinitionAST* funcDef = static_cast<FunctionDefinitionAST*>(ast->declarations->at(0)->element);
   QVERIFY(!funcDef->constructor_initializers);
   QVERIFY(funcDef->type_specifier);
-  QCOMPARE(stringForNode(funcDef->type_specifier).trimmed(), QString("void"));
+  QCOMPARE(lastSession->stringForNode(funcDef->type_specifier, true).trimmed(), QString("void"));
   QVERIFY(funcDef->function_body);
-  QCOMPARE(stringForNode(funcDef->function_body).trimmed(), QString("{}"));
+  QCOMPARE(lastSession->stringForNode(funcDef->function_body, true).trimmed(), QString("{}"));
   // ;
   QVERIFY(!ast->declarations->at(1)->element);
   }
