@@ -125,7 +125,7 @@ void MakeJob::start()
     setBehaviours(KDevelop::IOutputView::AllowUserClose | KDevelop::IOutputView::AutoScroll);
 
     setModel(new MakeOutputModel(buildDir), IOutputView::TakeOwnership);
-    setDelegate(m_builder->delegate());
+    setDelegate(new MakeOutputDelegate, IOutputView::TakeOwnership);
 
     startOutput();
 
