@@ -31,7 +31,11 @@ public:
     explicit TestMakeOutputModel(QObject* parent = 0);
 
 private slots:
+    void benchAddLongLine();
     void benchAddLines();
+
+    void testErrors_data();
+    void testErrors();
 };
 
 #endif // TEST_MAKEOUTPUTMODEL_H
