@@ -306,6 +306,7 @@ CMAKE_BEGIN_AST_CLASS( FindPackageAst ) //FIXME: there are things that I don't u
 CMAKE_ADD_AST_MEMBER( QString, name )
 CMAKE_ADD_AST_MEMBER( QString, version )
 CMAKE_ADD_AST_MEMBER( QStringList, components )
+CMAKE_ADD_AST_MEMBER( QStringList, paths )
 CMAKE_ADD_AST_MEMBER( bool, isQuiet )
 CMAKE_ADD_AST_MEMBER( bool, noModule )
 CMAKE_ADD_AST_MEMBER( bool, isRequired )
@@ -360,7 +361,7 @@ CMAKE_END_AST_CLASS( ForeachAst )
 
 
 CMAKE_BEGIN_AST_CLASS( GetCMakePropertyAst )
-    enum PropertyType { Variables, CacheVariables, Commands, Macros };
+    enum PropertyType { Variables, CacheVariables, Commands, Macros, Components };
 CMAKE_ADD_AST_MEMBER( PropertyType, type )
 CMAKE_ADD_AST_MEMBER( QString, variableName )
 CMAKE_END_AST_CLASS( GetCMakePropertyAst )
