@@ -416,7 +416,7 @@ void CMakeProjectVisitor::defineTarget(const QString& id, const QStringList& sou
     
     Target target;
     target.name=id.isEmpty() ? "<wrong-target>" : id;
-    target.declaration=d;
+    target.declaration=IndexedDeclaration(d);
     target.files=sources;
     target.type=t;
     target.desc=p.code->at(p.line);
@@ -570,8 +570,9 @@ int CMakeProjectVisitor::visit(const IncludeAst *inc)
             //FIXME: Put here the error.
             kDebug(9042) << "Include. Parsing error.";
         }
-        m_vars->remove("CMAKE_CURRENT_LIST_FILE");
-        m_vars->remove("CMAKE_CURRENT_LIST_DIR");
+        Q_ASSERT(m_vars->value("CMAKE_CURRENT_LIST_FILE")==QStringList(path));
+        m_vars->removeMulti("CMAKE_CURRENT_LIST_FILE");
+        m_vars->removeMulti("CMAKE_CURRENT_LIST_DIR");
     }
     else
     {
@@ -689,8 +690,8 @@ int CMakeProjectVisitor::visit(const FindPackageAst *pack)
         {
             m_vars->insertGlobal(QString("%1_CONFIG").arg(pack->name()), QStringList(path));
         }
-        m_vars->remove("CMAKE_CURRENT_LIST_FILE");
-        m_vars->remove("CMAKE_CURRENT_LIST_DIR");
+        m_vars->removeMulti("CMAKE_CURRENT_LIST_FILE");
+        m_vars->removeMulti("CMAKE_CURRENT_LIST_DIR");
         
         if(isConfig)
             m_vars->insert(pack->name()+"_FOUND", QStringList("TRUE"));
@@ -1042,7 +1043,7 @@ void CMakeProjectVisitor::macroDeclaration(const CMakeFunctionDesc& def, const C
     Identifier identifier(id);
     RangeInRevision sr=def.arguments.first().range();
     RangeInRevision endsr=end.arguments.first().range();
-    DUChainReadLocker lock;
+    DUChainWriteLocker lock;
     QList<Declaration*> decls=m_topctx->findDeclarations(identifier);
     
     //Only consider declarations in a CMake file
@@ -1053,9 +1054,7 @@ void CMakeProjectVisitor::macroDeclaration(const CMakeFunctionDesc& def, const C
         else
             it = decls.erase(it);
     }
-    lock.unlock();
-    
-    DUChainWriteLocker wlock;
+
     int idx;
     if(!decls.isEmpty())
     {
@@ -1141,13 +1140,11 @@ int CMakeProjectVisitor::visit(const MacroCallAst *call)
         else
         {
             {
-                DUChainReadLocker lock;
+                DUChainWriteLocker lock;
                 QList<Declaration*> decls=m_topctx->findDeclarations(Identifier(call->name().toLower()));
-                lock.unlock();
 
                 if(!decls.isEmpty())
                 {
-                    DUChainWriteLocker lock;
                     int idx=m_topctx->indexForUsedDeclaration(decls.first());
                     m_topctx->createUse(idx, call->content()[call->line()].nameRange(), 0);
                 }
@@ -1195,14 +1192,14 @@ int CMakeProjectVisitor::visit(const MacroCallAst *call)
             i=1;
             foreach(const QString& name, code.knownArgs)
             {
-                m_vars->take(QString("ARGV%1").arg(i));
-                m_vars->take(name);
+                m_vars->removeMulti(QString("ARGV%1").arg(i));
+                m_vars->removeMulti(name);
                 i++;
             }
 
-            m_vars->take("ARGV");
-            m_vars->take("ARGC");
-            m_vars->take("ARGN");
+            m_vars->removeMulti("ARGV");
+            m_vars->removeMulti("ARGC");
+            m_vars->removeMulti("ARGN");
 
         }
     }
@@ -1224,13 +1221,12 @@ void usesForArguments(const QStringList& names, const QList<int>& args, const Re
     foreach(int use, args)
     {
         QString var=names[use];
-        DUChainReadLocker lock;
+
+        DUChainWriteLocker lock;
         QList<Declaration*> decls=topctx->findDeclarations(Identifier(var));
-        lock.unlock();
 
         if(!decls.isEmpty() && func.arguments.count() > use)
         {
-            DUChainWriteLocker lock;
             CMakeFunctionArgument arg=func.arguments[use];
             int idx=topctx->indexForUsedDeclaration(decls.first());
             topctx->createUse(idx, RangeInRevision(arg.line-1, arg.column-1, arg.line-1, arg.column-1+var.size()), 0);
@@ -1738,7 +1734,7 @@ int CMakeProjectVisitor::visit(const ForeachAst *fea)
             {
                 m_vars->insertMulti(fea->loopVar(), QStringList(QString::number(i)));
                 end=walk(fea->content(), fea->line()+1);
-                m_vars->remove(fea->loopVar());
+                m_vars->removeMulti(fea->loopVar());
                 if(m_hitBreak)
                     break;
             }
@@ -2255,20 +2251,17 @@ void CMakeProjectVisitor::createDefinitions(const CMakeAst *ast)
         if(!arg.isCorrect())
             continue;
         Identifier id(arg.value);
-        
-        DUChainReadLocker lock;
+
+        DUChainWriteLocker lock;
         QList<Declaration*> decls=m_topctx->findDeclarations(id);
-        lock.unlock();
-        
+
         if(decls.isEmpty())
         {
-            DUChainWriteLocker lock;
             Declaration *d = new Declaration(arg.range(), m_topctx);
             d->setIdentifier(id);
         }
         else
         {
-            DUChainWriteLocker lock;
             int idx=m_topctx->indexForUsedDeclaration(decls.first());
             m_topctx->createUse(idx, arg.range(), 0);
         }
@@ -2290,13 +2283,11 @@ void CMakeProjectVisitor::createUses(const CMakeFunctionDesc& desc)
         {
             QString var=arg.value.mid(it->first+1, it->second-it->first-1);
             
-            DUChainReadLocker lock(DUChain::lock());
+            DUChainWriteLocker lock;
             QList<Declaration*> decls=m_topctx->findDeclarations(Identifier(var));
-            lock.unlock();
             
             if(!decls.isEmpty())
             {
-                DUChainWriteLocker lock(DUChain::lock());
                 int idx=m_topctx->indexForUsedDeclaration(decls.first());
                 m_topctx->createUse(idx, RangeInRevision(arg.line-1, arg.column+it->first, arg.line-1, arg.column+it->second-1), 0);
             }
