@@ -100,6 +100,9 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         void setMacroMap( MacroMap* macros ) { m_macros=macros; }
         void setModulePath(const QStringList& mp) { m_modulePath=mp; }
         void setDefinitions(const CMakeDefinitions& defs) { m_defs=defs; }
+        
+        /** sets the @p profile env variables that will be used to override those in the current system */
+        void setEnvironmentProfile(const QMap<QString, QString>& profile) { m_environmentProfile = profile; }
 
         const VariableMap* variables() const { return m_vars; }
         const CacheValues* cache() const { return m_cache; }
@@ -113,9 +116,6 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
             
         int walk(const CMakeFileContent& fc, int line, bool isClean=false);
         
-//         static VariableType hasVariable(const QString &name);
-        static QStringList envVarDirectories(const QString &varName);
-        
 //         enum FileType { Location, File, Executable, Library };
         static QString findFile(const QString& files, const QStringList &folders,
                                     const QStringList& suffixes=QStringList(), bool location=false);
@@ -137,6 +137,9 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         CMakeProperties properties() { return m_props; }
         
         static void setMessageCallback(message_callback f) { s_msgcallback=f; }
+        
+        QStringList variableValue(const QString& var) const;
+        
     protected:
         struct IntPair
         {
@@ -155,6 +158,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         static QList< IntPair > parseArgument(const QString &exp);
         
     private:
+        QStringList envVarDirectories(const QString &varName) const;
         static message_callback s_msgcallback;
         
         static KDevelop::ReferencedTopDUContext
@@ -177,7 +181,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
 
         QStringList traverseGlob(const QString& startPath, const QString& expression,
             bool recursive = false, bool followSymlinks = false);
-
+        
         CMakeProperties m_props;
         QStringList m_modulePath;
         QString m_projectName;
@@ -195,7 +199,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         KDevelop::ReferencedTopDUContext m_topctx;
         KDevelop::ReferencedTopDUContext m_parentCtx;
         bool m_hitBreak;
-
+        QMap<QString, QString> m_environmentProfile;
 };
 
 #endif
